/*
 *
 * Copyright (c) International Business Machines  Corp., 2005
 * This program is free software;  you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY;  without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program;  if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Test name: balloon07
 * Author: Paul Larson <pl@us.ibm.com>
 * Description: Open /proc/xen/balloon as non-root user, expect -EACCES
 */

#include <errno.h>
#include <fcntl.h>
#include <pwd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>

#define TESTNAME "balloon07"

int main(void)
{
	int fd;
	int err;
	char username[] = "nobody";
	struct passwd *user;

	user = getpwnam(username);

	if (setreuid(user->pw_uid, user->pw_uid) == -1) {
		printf("%s FAIL: setreuid(): %s\n",TESTNAME, strerror(errno));
		exit(1);
	}

	fd = open("/proc/xen/balloon", O_RDWR);
	err = errno;
	if (fd != -1) {
		printf("%s FAIL: Write to /proc/xen/balloon as non-root "
		       "user succeeded\n", TESTNAME);
		close(fd);
		exit(1);
	}
	if (err != 13) {
		printf("%s FAIL: Write to /proc/xen/balloon as non-root "
		       "got errno %d, expected 13\n", TESTNAME, err);
		close(fd);
		exit(1);
	}
	printf("%s PASS: Write to /proc/xen/balloon as non-root user failed "
	       "with -EACCES\n", TESTNAME);
	close(fd);
	exit(0);
}

