/*
 *
 * Copyright (c) International Business Machines  Corp., 2005
 * This program is free software;  you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY;  without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program;  if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Test name: balloon09
 * Author: Paul Larson <pl@us.ibm.com>
 * Description: Write >64 bytes to /proc/xen/balloon, expect -EFBIG
 */

#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>

#define TESTNAME "balloon09"
#define STRSIZE 100

int main(void)
{
	int fd;
	int ret, err, i;
	char str[STRSIZE];

	for(i=0;i<64;i++) {
		*(str + i) = 'a';
	}

	fd = open("/proc/xen/balloon", O_RDWR);
	if (fd == -1) {
		printf("%s FAIL: failed to open /proc/xen/balloon, %s\n",
			TESTNAME, strerror(errno));
		exit(1);
	}
	ret = write(fd, str, sizeof(str));
	err = errno;
	if (ret != -1) {
		printf("%s FAIL: Write 1 byte to /proc/xen/balloon succeeded\n",
			TESTNAME);
		close(fd);
		exit(1);
	}
	if (err != 27) {
		printf("%s FAIL: Write 1 byte got errno %d, expected 27\n",
			TESTNAME, err);
		close(fd);
		exit(1);
	}
	printf("%s PASS: Write 1 byte failed with -EFBIG as expected\n",
		TESTNAME);
	close(fd);
	exit(0);
}

